@@ -21,8 +21,7 @@ import refnx.reduce._app as floc
 matplotlib.use("QtAgg")
 
 
-with resources.files(floc) as _p:
-    UI_LOCATION = _p / "ui"
+UI_LOCATION = resources.files(floc) / "ui"
 
 
 class ManualBeamFinder(QtWidgets.QDialog):
